@@ -7,7 +7,7 @@ perldocSearch.indexData.modules = new Hash ({
   "bignum": "Transparent BigNumber support for Perl",
   "bigrat": "Transparent BigNumber/BigRational support for Perl",
   "blib": "Use MakeMaker's uninstalled version of a package",
-  "bytes": "Perl pragma to force byte semantics rather than character semantics",
+  "bytes": "Perl pragma to expose the individual bytes of characters",
   "charnames": "access to Unicode character names and named character sequences; also define character names",
   "constant": "Perl pragma to declare constants",
   "diagnostics": "produce verbose warning diagnostics",
@@ -41,8 +41,8 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Simple": "framework for parsing Pod",
   "Config": "access Perl configuration information",
   "Params::Check": "A generic input parsing/checking mechanism.",
-  "ExtUtils::MM_MacOS": "once produced Makefiles for MacOS Classic",
   "ExtUtils::Embed": "Utilities for embedding Perl in C/C++ applications",
+  "ExtUtils::MM_MacOS": "once produced Makefiles for MacOS Classic",
   "Text::Tabs": "expand and unexpand tabs like unix expand(1) and unexpand(1)",
   "ExtUtils::MakeMaker": "Create a module Makefile",
   "PerlIO::encoding": "encoding layer",
@@ -51,8 +51,8 @@ perldocSearch.indexData.modules = new Hash ({
   "File::stat": "by-name interface to Perl's built-in stat() functions",
   "Pod::Simple::PullParserEndToken": "end-tokens from Pod::Simple::PullParser",
   "Math::Complex": "complex numbers and associated mathematical functions",
-  "File::DosGlob": "DOS like globbing and then some",
   "ExtUtils::MM_VMS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
+  "File::DosGlob": "DOS like globbing and then some",
   "IO::Poll": "Object interface to system poll call",
   "File::Spec::Functions": "portably perform operations on file names",
   "Socket": "networking constants and support functions",
@@ -189,7 +189,7 @@ perldocSearch.indexData.modules = new Hash ({
   "Locale::Maketext::Guts": "Deprecated module to load Locale::Maketext utf8 code",
   "ExtUtils::Mkbootstrap": "make a bootstrap file for use by DynaLoader",
   "Pod::Usage": "print a usage message from embedded pod documentation",
-  "Pod::Text": "Convert POD data to formatted ASCII text",
+  "Pod::Text": "Convert POD data to formatted text",
   "Pod::ParseUtils": "helpers for POD parsing and conversion",
   "Pod::Perldoc::ToPod": "let Perldoc render Pod as ... Pod!",
   "CPAN::Version": "utility functions to compare CPAN versions",
@@ -197,7 +197,7 @@ perldocSearch.indexData.modules = new Hash ({
   "Safe": "Compile and execute code in restricted compartments",
   "IO::File": "supply object methods for filehandles",
   "ExtUtils::ParseXS": "converts Perl XS code into C code",
-  "Encode::MIME::Header": "MIME 'B' and 'Q' header encoding",
+  "Encode::MIME::Header": "MIME encoding for an unstructured email header",
   "File::Find": "Traverse a directory tree.",
   "DBM_Filter::encode": "filter for DBM_Filter",
   "Test": "provides a simple framework for writing test scripts",
@@ -299,12 +299,12 @@ perldocSearch.indexData.modules = new Hash ({
   "Time::gmtime": "by-name interface to Perl's built-in gmtime() function",
   "IPC::SharedMem": "SysV Shared Memory IPC object class",
   "App::Prove::State": "State storage for the prove command.",
+  "Time::Local": "Efficiently compute time from local and GMT time",
   "DBM_Filter::utf8": "filter for DBM_Filter",
-  "Time::Local": "efficiently compute time from local and GMT time",
   "Pod::Simple::RTF": "format Pod as RTF",
   "Pod::ParseLink": "Parse an L&lt;&gt; formatting code in POD text",
-  "Pod::Simple::PullParser": "a pull-parser interface to parsing Pod",
   "Tie::Handle": "base class definitions for tied handles",
+  "Pod::Simple::PullParser": "a pull-parser interface to parsing Pod",
   "Memoize::ExpireFile": "test for Memoize expiration semantics",
   "IO::Select": "OO interface to the select system call",
   "Locale::Maketext": "framework for localization",
@@ -319,7 +319,7 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Parser::IteratorFactory": "Figures out which SourceHandler objects to use for a given Source",
   "TAP::Harness": "Run test scripts with statistics",
   "Net::Config": "Local configuration data for libnet",
-  "ExtUtils::Miniperl": "write the C code for perlmain.c",
+  "ExtUtils::Miniperl": "write the C code for miniperlmain.c and perlmain.c",
   "Archive::Tar::File": "a subclass for in-memory extracted file from Archive::Tar",
   "TAP::Parser::Iterator::Stream": "Iterator for filehandle-based TAP sources",
   "Pod::Simple::LinkSection": "represent \"section\" attributes of L codes",
@@ -345,8 +345,8 @@ perldocSearch.indexData.modules = new Hash ({
   "Math::BigInt::Calc": "Pure Perl module to support Math::BigInt",
   "TAP::Parser::Grammar": "A grammar for the Test Anything Protocol.",
   "File::Spec::Mac": "File::Spec for Mac OS (Classic)",
-  "XSLoader": "Dynamically load C libraries into Perl code",
   "Filter::Simple": "Simplified source filtering",
+  "XSLoader": "Dynamically load C libraries into Perl code",
   "IO::Handle": "supply object methods for I/O handles",
   "TAP::Formatter::Console::Session": "Harness output delegate for default console output",
   "Carp": "alternative warn and die for modules",
