@@ -64,7 +64,7 @@ perldocSearch.indexData.pod = new Hash ({
   "perllocale": "Perl locale handling (internationalization and localization)",
   "perluniintro": "Perl Unicode introduction",
   "perlunicode": "Unicode support in Perl",
-  "perluniprops": "Index of Unicode Version 7.0.0 character properties in Perl",
+  "perluniprops": "Index of Unicode Version 9.0.0 character properties in Perl",
   "perlunicook": "cookbookish examples of handling Unicode in Perl",
   "perlebcdic": "Considerations for running Perl on EBCDIC platforms",
   "perlsec": "Perl security",
@@ -102,20 +102,16 @@ perldocSearch.indexData.pod = new Hash ({
   "perlpolicy": "Various and sundry policies and commitments related to the Perl core",
   "perlhist": "the Perl history records",
   "perltodo": "Link to the Perl to-do list",
-  "perldelta": "what is new for perl v5.22.0",
+  "perldelta": "what is new for perl v5.26.0",
+  "perldeprecation": "list Perl deprecations",
+  "perl5260delta": "what is new for perl v5.26.0",
+  "perl5241delta": "what is new for perl v5.24.1",
+  "perl5240delta": "what is new for perl v5.24.0",
+  "perl5223delta": "what is new for perl v5.22.3",
+  "perl5222delta": "what is new for perl v5.22.2",
+  "perl5221delta": "what is new for perl v5.22.1",
   "perl5220delta": "what is new for perl v5.22.0",
-  "perl52111delta": "what is new for perl v5.21.11",
-  "perl52110delta": "what is new for perl v5.21.10",
-  "perl5219delta": "what is new for perl v5.21.9",
-  "perl5218delta": "what is new for perl v5.21.8",
-  "perl5217delta": "what is new for perl v5.21.7",
-  "perl5216delta": "what is new for perl v5.21.6",
-  "perl5215delta": "what is new for perl v5.21.5",
-  "perl5214delta": "what is new for perl v5.21.4",
-  "perl5213delta": "what is new for perl v5.21.3",
-  "perl5212delta": "what is new for perl v5.21.2",
-  "perl5211delta": "what is new for perl v5.21.1",
-  "perl5210delta": "what is new for perl v5.21.0",
+  "perl5203delta": "what is new for perl v5.20.3",
   "perl5202delta": "what is new for perl v5.20.2",
   "perl5201delta": "what is new for perl v5.20.1",
   "perl5200delta": "what is new for perl v5.20.0",
@@ -157,7 +153,7 @@ perldocSearch.indexData.pod = new Hash ({
   "perlartistic": "the Perl Artistic License",
   "perlgpl": "the GNU General Public License, version 1",
   "perlaix": "Perl version 5 on IBM AIX (UNIX) systems",
-  "perlamiga": "Perl under Amiga OS",
+  "perlamiga": "Perl under AmigaOS 4.1",
   "perlbs2000": "building and installing Perl for BS2000.",
   "perlce": "Perl for WinCE",
   "perlcygwin": "Perl for Cygwin",
@@ -185,7 +181,6 @@ perldocSearch.indexData.pod = new Hash ({
   "perlvos": "Perl for Stratus OpenVOS",
   "perlwin32": "Perl under Windows",
   "perlutil": "utilities packaged with the Perl distribution",
-  "c2ph": "Dump C structures as generated from cc -g -S stabs",
   "corelist": "a commandline frontend to Module::CoreList",
   "cpan": "easily interact with CPAN from the command line",
   "enc2xs": "Perl Encode Module Generator",
@@ -204,8 +199,7 @@ perldocSearch.indexData.pod = new Hash ({
   "pod2text": "Convert POD data to formatted ASCII text",
   "pod2usage": "print usage messages from embedded pod docs in files",
   "podselect": "print selected sections of pod documentation on standard output",
-  "pstruct": "Dump C structures as generated from cc -g -S stabs",
-  "ptar": "1",
+  "ptar": "a tar-like program written in perl",
   "ptardiff": "program that diffs an extracted archive against an unextracted one",
   "shasum": "Print or Check SHA Checksums",
   "splain": "produce verbose warning diagnostics",
